Enum ArgumentExpr
pub enum ArgumentExpr {
ByValue(ValueExpr),
InPlace(PlaceExpr),
}Expand description
Function arguments can be passed by-value or in-place.
Variants
ByValue(ValueExpr)
Pass a copy of this value to the function.
Technically this could be encoded by generating a fresh temporary, copying the value there, and doing in-place passing. FIXME: is it worth providing this mode anyway?
InPlace(PlaceExpr)
Pass the argument value in-place; the contents of this place may be altered arbitrarily by the callee.