Enum BinOp
pub enum BinOp {
Int(IntBinOp),
IntWithOverflow(IntBinOpWithOverflow),
Rel(RelOp),
PtrOffset {
inbounds: bool,
},
PtrOffsetFrom {
inbounds: bool,
nonneg: bool,
},
ConstructWidePointer(PtrType),
}Variants
Int(IntBinOp)
An operation on integers (both must have the same type); returns an integer of the same type.
IntWithOverflow(IntBinOpWithOverflow)
An operation on integers (both must have the same type); returns a tuple of integer of the same type and a boolean that is true if the result is not equal to the infinite-precision result.
Rel(RelOp)
Compares two values according to the given relational operator. Both must have the same type, and they must both be integers, Booleans, or pointers.
PtrOffset
Add a byte-offset to a pointer (with or without inbounds requirement). Takes a pointer as left operand and an integer as right operand; returns a pointer. FIXME: should we make this in units of the pointee size? The thing is, for raw pointers we do not have the pointee type…
PtrOffsetFrom
Compute the distance between two pointers in bytes (with or without inbounds requirement).
Takes two pointers; returns a signed pointer-sized integer.
If nonneg is true, it is UB for the result to be negative.
ConstructWidePointer(PtrType)
This corresponds to core::ptr::from_raw_parts
and takes a thin pointer and matching metadata to construct a pointer of the given type.
When the target type is a thin pointer and the metadata is (), this is just a pointer cast.