Enum CastOp
pub enum CastOp {
IntToInt(IntType),
Transmute(Type),
}Variants
IntToInt(IntType)
Argument can be any integer type; returns the given integer type.
Transmute(Type)
Transmute the value to a different type. The program is well-formed even if the output type has a different size than the input type, but the operation is UB in that case.