Enum Constant
pub enum Constant {
Int(Int),
Bool(bool),
GlobalPointer(Relocation),
FnPointer(FnName),
VTablePointer(VTableName),
PointerWithoutProvenance(Int),
}Expand description
Constants are basically values, but cannot have explicit provenance. Currently we do not support Ptr and Union constants.
Variants
Int(Int)
A mathematical integer, used for i*/u* types.
Bool(bool)
A Boolean value, used for bool.
GlobalPointer(Relocation)
A pointer pointing into a global allocation with a given offset.
FnPointer(FnName)
A pointer pointing to a function.
VTablePointer(VTableName)
A pointer pointing to a vtable.
PointerWithoutProvenance(Int)
A pointer with constant address, not pointing into any allocation.