Enum Discriminator
pub enum Discriminator {
Known(Int),
Invalid,
Branch {
offset: Size,
value_type: IntType,
fallback: GcCow<Discriminator>,
children: Map<(Int, Int), Discriminator>,
},
}Expand description
The decision tree that computes the discriminant out of the tag for a specific enum type.
Variants
Known(Int)
We know the discriminant.
Invalid
Tag decoding failed, there is no valid discriminant.
Branch
We don’t know the discriminant, so we branch on the value of a specific value.