Enum IntBinOp
pub enum IntBinOp {
Show 16 variants
Add,
AddUnchecked,
Sub,
SubUnchecked,
Mul,
MulUnchecked,
Div,
DivExact,
Rem,
Shl,
ShlUnchecked,
Shr,
ShrUnchecked,
BitAnd,
BitOr,
BitXor,
}Variants
Add
Add two integer values.
AddUnchecked
Add two integer values. Throws UB on overflow.
Sub
Subtract two integer values.
SubUnchecked
Subtract two integer values. Throws UB on overflow.
Mul
Multiply two integer values.
MulUnchecked
Multiply two integer values. Throws UB on overflow.
Div
Divide two integer values.
UB on division by zero and on int::MIN / -1.
DivExact
Divide two integer values.
UB on division by zero, on int::MIN / -1, and on a non-zero remainder.
Rem
Remainder of a division, the % operator.
UB if the modulos (right operand) is zero and on int::MIN % -1.
Shl
Shift left <<
ShlUnchecked
Shift left <<
Throws UB if right operand not in range 0..left::BITS.
Shr
Shift right >> (logical shift for unsigned integers, arithmetic shift for signed integers)
ShrUnchecked
Shift right >> (logical shift for unsigned integers, arithmetic shift for signed integers)
Throws UB if right operand not in range 0..left::BITS.
BitAnd
Bitwise-and two integer values.
BitOr
Bitwise-or two integer values.
BitXor
Bitwise-xor two integer values.