Enum IntBinOpWithOverflow
pub enum IntBinOpWithOverflow {
Add,
Sub,
Mul,
}Variants
Add
Add two integer values, returns a tuple of the result integer and a bool indicating whether the calculation overflowed.
Sub
Subtract two integer values, returns a tuple of the result integer and a bool indicating whether the calculation overflowed.
Mul
Multiply two integers, returns a tuple of the result integer and a bool indicating whether the calculation overflowed.