Enum IntrinsicOp
pub enum IntrinsicOp {
Show 18 variants
Abort,
Assume,
Exit,
PrintStdout,
PrintStderr,
Allocate,
Deallocate,
Spawn,
Join,
RawEq,
AtomicStore,
AtomicLoad,
AtomicCompareExchange,
AtomicFetchAndOp(IntBinOp),
Lock(IntrinsicLockOp),
PointerExposeProvenance,
PointerWithExposedProvenance,
GetUnwindPayload,
}Expand description
The intrinsic operations supported by MiniRust.
Generally we only make things intrinsics if they cannot be operands, i.e.
they are non-deterministic or mutate the global state.
We also make them intrinsic if they return (), because an operand that
does not return anything is kind of odd.
Variants
Abort
Assume
Exit
PrintStdout
PrintStderr
Allocate
Deallocate
Spawn
Join
RawEq
Determines whether the raw bytes pointed to by two pointers are equal. (Can’t be an operand because it reads from memory.)
AtomicStore
AtomicLoad
AtomicCompareExchange
AtomicFetchAndOp(IntBinOp)
Lock(IntrinsicLockOp)
PointerExposeProvenance
‘Expose’ the provenance a pointer so that it can later be cast to an integer.
The address part of the pointer is stored in destination.
PointerWithExposedProvenance
Create a new pointer from the given address with some previously exposed provenance.
GetUnwindPayload
Access the current unwinding payload. UB if not currently unwinding.