Enum PointerMeta
pub enum PointerMeta<Provenance>where
Provenance: Obj,{
ElementCount(Int),
VTablePointer(ThinPointer<Provenance>),
}Expand description
The runtime metadata that can be stored in a wide pointer.
Variants
ElementCount(Int)
The metadata counts the number of elements in the slice.
VTablePointer(ThinPointer<Provenance>)
The metadata points to a vtable referred at this location. This must point to a valid vtable and it is a spec bug if it doesn’t.