Enum PointerMetaKind
pub enum PointerMetaKind {
None,
ElementCount,
VTablePointer(TraitName),
}Expand description
The statically known kind of metadata stored in a pointer.
This determines the type of the metadata, while Option<PointerMeta> determines its value.
Variants
Implementations
impl PointerMetaKind
impl PointerMetaKind