Enum PtrType
pub enum PtrType {
Ref {
mutbl: Mutability,
pointee: PointeeInfo,
},
Box {
pointee: PointeeInfo,
},
Raw {
meta_kind: PointerMetaKind,
},
FnPtr,
VTablePtr(TraitName),
}Expand description
Stores all the information that we need to know about a pointer.
Variants
Ref
Fields

mutbl: MutabilityIndicates a shared vs mutable reference.

pointee: PointeeInfoDescribes what we know about the pointee.
Box
Fields

pointee: PointeeInfoRaw
Fields

meta_kind: PointerMetaKindIndicates what kind of metadata this pointer carries.
FnPtr
VTablePtr(TraitName)
This is a “stand-alone” vtable pointer, something that does not exist in surface Rust.
Implementations
impl PtrType
impl PtrType
pub fn as_wide_pair<T>(self) -> Option<Type>where
T: Target + Obj,
pub fn as_wide_pair<T>(self) -> Option<Type>where
T: Target + Obj,
Returns a pair type representing this wide pointer or None if it is thin.
impl PtrType
impl PtrType
pub fn safe_pointee(self) -> Option<PointeeInfo>
pub fn safe_pointee(self) -> Option<PointeeInfo>
If this is a safe pointer, return the pointee information.
pub fn meta_kind(self) -> PointerMetaKind