Statement

Enum Statement 

pub enum Statement {
    Assign {
        destination: PlaceExpr,
        source: ValueExpr,
    },
    PlaceMention(PlaceExpr),
    SetDiscriminant {
        destination: PlaceExpr,
        value: Int,
    },
    Validate {
        place: PlaceExpr,
        fn_entry: bool,
    },
    Deinit {
        place: PlaceExpr,
    },
    StorageLive(LocalName),
    StorageDead(LocalName),
}

Variants



Assign

Copy value from source to destination.

Fields

destination: PlaceExpr
source: ValueExpr


PlaceMention(PlaceExpr)

Evaluate a place without accessing it. This is the result of translating e.g. let _ = place;.



SetDiscriminant

Set the discriminant of the variant at destination to value.

Fields

destination: PlaceExpr
value: Int


Validate

Ensure that place contains a valid value of its type (else UB). Also perform retagging and ensure safe pointers are dereferenceable.

The frontend is generally expected to generate this for all function argument, and possibly in more places.

Fields

fn_entry: bool

Indicates whether this operation occurs as part of the prelude that we have at the top of each function (which affects retagging).



Deinit

De-initialize a place.

Fields



StorageLive(LocalName)

Allocate the backing store for this local.



StorageDead(LocalName)

Deallocate the backing store for this local.