Type

Enum Type 

pub enum Type {
    Int(IntType),
    Bool,
    Ptr(PtrType),
    Tuple {
        sized_fields: List<(Size, Type)>,
        sized_head_layout: TupleHeadLayout,
        unsized_field: GcCow<Option<Type>>,
    },
    Array {
        elem: GcCow<Type>,
        count: Int,
    },
    Slice {
        elem: GcCow<Type>,
    },
    Union {
        fields: List<(Size, Type)>,
        chunks: List<(Size, Size)>,
        size: Size,
        align: Align,
    },
    Enum {
        variants: Map<Int, Variant>,
        discriminant_ty: IntType,
        discriminator: Discriminator,
        size: Size,
        align: Align,
    },
    TraitObject(TraitName),
}
The types of MiniRust.

Variants



Int(IntType)



Bool



Ptr(PtrType)

Ptr represents all pointer types: references, raw pointers, boxes, function and vtable pointers. A pointer type does not need the full pointee type, since (de)serializing a pointer does not require knowledge about the pointee. We only track the metadata kind and basic pointee information like size and alignment that is required to check reference validity. This also means types have a finite representation even when the Rust type is recursive.



Tuple

“Tuple” is used for all heterogeneous types, i.e., both Rust tuples and structs.

Fields

sized_fields: List<(Size, Type)>

Fields must not overlap.

sized_head_layout: TupleHeadLayout

The layout of the sized fiels, i.e., the head.

unsized_field: GcCow<Option<Type>>

A last field (in terms of offset), i.e., the tail, may contain an unsized type, then its offset is given by rounding the end of sized_head_layout up to the alignment of this type.



Array

Fields

elem: GcCow<Type>
count: Int


Slice

Slices, i.e. [T] are unsized types which therefore cannot be represented as values. This type is also used for strings: str are treated as [u8].

Fields

elem: GcCow<Type>


Union

Fields

fields: List<(Size, Type)>

Fields may overlap. Fields only exist for field access place projections, they are irrelevant for the representation relation.

chunks: List<(Size, Size)>

A union can be split into multiple “chunks”, where only the data inside those chunks is preserved, and data between chunks is lost (like padding in a struct). This is necessary to model the behavior of some repr(C) unions, see https://github.com/rust-lang/unsafe-code-guidelines/issues/156 for details.

size: Size

The total size of the union, can indicate padding after the last chunk.

align: Align

Total alignment of the union. Due to repr(packed) and repr(align), this is independent of the fields’ alignment.



Enum

Fields

variants: Map<Int, Variant>

The map variants, each identified by a discriminant. Each variant is given by a type and its tag description. All variants are thought to “start at offset 0”; if the discriminant is encoded as an explicit tag, then that will be put into the padding of the active variant. (This means it is not safe to hand out mutable references to a variant at that type, as then the tag might be overwritten!) The Rust type ! is encoded as an Enum with an empty list of variants.

discriminant_ty: IntType

The IntType for the discriminant. This is used for the type of GetDiscriminant and SetDiscriminant. It is entirely independent of how the discriminant is represented in memory (the “tag”).

discriminator: Discriminator

The decision tree to decode the discriminant from the tag at runtime.

size: Size

The total size of the enum can indicate trailing padding. Must be large enough to contain all variants.

align: Align

Total alignment of the enum. Due to repr(packed) and repr(align), this is independent of the fields’ alignment.



TraitObject(TraitName)

A dyn TraitName. Commonly only used behind a pointer.

Implementations



impl Type

pub fn layout<T>(self) -> LayoutStrategy
where T: Target + Obj,

The layout, i.e. the size and align of the type. For ?Sized types, this needs to be computed.

pub fn meta_kind(self) -> PointerMetaKind

Returns the metadata kind when this type is used as a pointee. This matches the meta kind of the layout, but without needing to specify a target.