Enum UnOp
pub enum UnOp {
Int(IntUnOp),
Cast(CastOp),
GetThinPointer,
GetMetadata,
ComputeSize(Type),
ComputeAlign(Type),
VTableMethodLookup(TraitMethodName),
}Variants
Int(IntUnOp)
An operation on an integer; returns an integer of the same type.
Cast(CastOp)
A form of cast; the return type is given by the specific cast operation.
GetThinPointer
Returns a raw pointer with same thin pointer as the operand, but without the metadata.
GetMetadata
Returns the metadata of a pointer as a value.
The return type is given by PointerMetaKind::ty(), e.g., for a thin pointer this is ().
ComputeSize(Type)
Returns the dynamic size of the type given the pointer metadata.
The operand must be a matching metadata for the type. For sized types this is ().
ComputeAlign(Type)
Returns the dynamic alignment of the type given the pointer metadata.
The operand must be a matching metadata for the type. For sized types this is ().
VTableMethodLookup(TraitMethodName)
Lookup the function pointer for a trait object method.
The operand must be a pointer to a vtable as returned by Constant::VTablePointer.
The parameter specifies which method of the vtable to look up.