Enum UnsafeCellStrategy
pub enum UnsafeCellStrategy {
Sized {
cells: List<(Size, Size)>,
},
Slice {
element_cells: List<(Size, Size)>,
},
TraitObject,
Tuple {
head_cells: List<(Size, Size)>,
tail_cells: GcCow<UnsafeCellStrategy>,
},
}Expand description
Describes where in a potentially unsized type the UnsafeCell are.
Separate from LayoutStrategy since we must be able to compute LayoutStrategy from a
MiniRust Type, but that does not have enough information for an UnsafeCellStrategy.
FIXME: maybe it should?
Variants
Sized
List of offsets and sizes of UnsafeCells.
Slice
Since the elements of a slice have the same type, we only keep track of the UnsafeCell’s of one element, we can then “repeat” this for the rest of the slice.
TraitObject
The bytes for UnsafeCell’s must be looked up in the VTable.
Tuple
A Tuple consists of a sized head an unsized tail.