Struct Align
pub struct Align {
raw: Int,
}Expand description
This type is basically a copy of the Align type in the Rust compiler.
See Align.
Fields
raw: IntImplementations
impl Align
impl Align
pub fn from_bytes(align: impl Into<Int>) -> Option<Align>
pub fn from_bytes(align: impl Into<Int>) -> Option<Align>
Constructs Align with align many bytes.
Returns None if align is not a power of two.
pub const fn from_bytes_const(align: u64) -> Option<Align>
pub const fn from_bytes_const(align: u64) -> Option<Align>
Variation of from_bytes for const contexts.
pub fn from_bits(align: impl Into<Int>) -> Option<Align>
pub fn from_bits(align: impl Into<Int>) -> Option<Align>
Constructs Align with align many bits.
Returns None if align is not divisible by 8, or if align/8 is no power of two.
pub const fn from_bits_const(align: u64) -> Option<Align>
pub const fn from_bits_const(align: u64) -> Option<Align>
Variation of from_bits for const contexts.
pub fn max_for_offset(offset: Size) -> Option<Align>
pub fn max_for_offset(offset: Size) -> Option<Align>
Computes the best alignment possible for the given offset
(the largest power of two that the offset is a multiple of).
For an offset of 0 it returns None.
pub fn restrict_for_offset(self, offset: Size) -> Align
pub fn restrict_for_offset(self, offset: Size) -> Align
Lower the alignment if necessary, such that the given offset is aligned to it (the offset is a multiple of the alignment).
pub fn is_aligned(self, addr: Int) -> bool
pub fn is_aligned(self, addr: Int) -> bool
Check if the given address is sufficiently aligned.