Struct ConcurrentMemory
pub struct ConcurrentMemory<M>where
M: Memory + Obj,{
memory: M,
accesses: List<Access>,
}Fields
memory: Maccesses: List<Access>Implementations
impl<M> ConcurrentMemory<M>where
M: Memory + Obj,
impl<M> ConcurrentMemory<M>where
M: Memory + Obj,
pub fn new(params: <M as Memory>::Params) -> ConcurrentMemory<M>
pub fn allocate(
&mut self,
kind: AllocationKind,
size: Size,
align: Align,
) -> NdResult<ThinPointer<<M as Memory>::Provenance>, TerminationInfo>
pub fn allocate( &mut self, kind: AllocationKind, size: Size, align: Align, ) -> NdResult<ThinPointer<<M as Memory>::Provenance>, TerminationInfo>
Create a new allocation.
The initial contents of the allocation are AbstractByte::Uninit.
pub fn deallocate(
&mut self,
ptr: ThinPointer<<M as Memory>::Provenance>,
kind: AllocationKind,
size: Size,
align: Align,
) -> Result<(), TerminationInfo>
pub fn deallocate( &mut self, ptr: ThinPointer<<M as Memory>::Provenance>, kind: AllocationKind, size: Size, align: Align, ) -> Result<(), TerminationInfo>
Remove an allocation.
pub fn store(
&mut self,
ptr: ThinPointer<<M as Memory>::Provenance>,
bytes: List<AbstractByte<<M as Memory>::Provenance>>,
align: Align,
atomicity: Atomicity,
) -> Result<(), TerminationInfo>
pub fn store( &mut self, ptr: ThinPointer<<M as Memory>::Provenance>, bytes: List<AbstractByte<<M as Memory>::Provenance>>, align: Align, atomicity: Atomicity, ) -> Result<(), TerminationInfo>
Write some bytes to memory and check for data races.
pub fn load(
&mut self,
ptr: ThinPointer<<M as Memory>::Provenance>,
len: Size,
align: Align,
atomicity: Atomicity,
) -> Result<List<AbstractByte<<M as Memory>::Provenance>>, TerminationInfo>
pub fn load( &mut self, ptr: ThinPointer<<M as Memory>::Provenance>, len: Size, align: Align, atomicity: Atomicity, ) -> Result<List<AbstractByte<<M as Memory>::Provenance>>, TerminationInfo>
Read some bytes from memory and check for data races.
pub fn dereferenceable(
&self,
ptr: ThinPointer<<M as Memory>::Provenance>,
len: Size,
) -> Result<(), TerminationInfo>
pub fn dereferenceable( &self, ptr: ThinPointer<<M as Memory>::Provenance>, len: Size, ) -> Result<(), TerminationInfo>
Test whether the given pointer is dereferenceable for the given size. Raises UB if that is not the case.
pub fn signed_dereferenceable(
&self,
ptr: ThinPointer<<M as Memory>::Provenance>,
len: Int,
) -> Result<(), TerminationInfo>
pub fn signed_dereferenceable( &self, ptr: ThinPointer<<M as Memory>::Provenance>, len: Int, ) -> Result<(), TerminationInfo>
A derived form of dereferenceable that works with a signed notion on “length”.
pub fn retag_ptr(
&mut self,
frame_extra: &mut <M as Memory>::FrameExtra,
ptr: Pointer<<M as Memory>::Provenance>,
ptr_type: PtrType,
fn_entry: bool,
fn_implicit_writes: bool,
vtable_lookup: impl Fn(ThinPointer<<M as Memory>::Provenance>) -> VTable + 'static,
) -> Result<Pointer<<M as Memory>::Provenance>, TerminationInfo>
pub fn retag_ptr( &mut self, frame_extra: &mut <M as Memory>::FrameExtra, ptr: Pointer<<M as Memory>::Provenance>, ptr_type: PtrType, fn_entry: bool, fn_implicit_writes: bool, vtable_lookup: impl Fn(ThinPointer<<M as Memory>::Provenance>) -> VTable + 'static, ) -> Result<Pointer<<M as Memory>::Provenance>, TerminationInfo>
Return the retagged pointer.
pub fn end_call(
&mut self,
extra: <M as Memory>::FrameExtra,
) -> Result<(), TerminationInfo>
pub fn end_call( &mut self, extra: <M as Memory>::FrameExtra, ) -> Result<(), TerminationInfo>
Memory model hook invoked at the end of each function call.
pub fn leak_check(&self) -> Result<(), TerminationInfo>
pub fn leak_check(&self) -> Result<(), TerminationInfo>
Check if there are any memory leaks.
pub fn check_data_races(
&self,
current_thread: Int,
_: (Set<Int>, List<Access>),
) -> Result<(), TerminationInfo>
pub fn check_data_races( &self, current_thread: Int, _: (Set<Int>, List<Access>), ) -> Result<(), TerminationInfo>
Given a list of previous accesses, checks if any of the current accesses is in a data race with any of those.
pub fn reset_accesses(&mut self) -> List<Access>
pub fn reset_accesses(&mut self) -> List<Access>
Prepare memory to track accesses of next step: reset the internal access list to be empty, and return the list of previously collected accesses.