Struct FnName
pub struct FnName(pub Name);Expand description
Opaque types of names for functions, vtables, trait methods, and globals. The internal representations of these types do not matter.
Tuple Fields
0: NameTrait Implementations
impl Copy for FnName
impl<'de> Deserialize<'de> for FnName
impl<'de> Deserialize<'de> for FnName
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FnName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FnName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FnName
impl Ord for FnName
impl Ord for FnName
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
impl PartialOrd for FnName
impl PartialOrd for FnName
impl Serialize for FnName
impl Serialize for FnName
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for FnName