Struct Function
pub struct Function {
pub locals: Map<LocalName, Type>,
pub args: List<LocalName>,
pub ret: LocalName,
pub calling_convention: CallingConvention,
pub blocks: Map<BbName, BasicBlock>,
pub start: BbName,
pub implicit_writes: bool,
}Expand description
A MiniRust function.
Fields
locals: Map<LocalName, Type>The locals of this function, and their type.
args: List<LocalName>A list of locals that are initially filled with the function arguments.
ret: LocalNameThe name of a local that holds the return value when the function returns.
calling_convention: CallingConventionThe call calling convention of this function.
blocks: Map<BbName, BasicBlock>Associate each basic block name with the associated block.
start: BbNameThe basic block where execution starts.
implicit_writes: boolWhether implicit writes are enabled for this function.