Global

Struct Global 

pub struct Global {
    pub bytes: List<Option<u8>>,
    pub relocations: List<(Size, Relocation)>,
    pub align: Align,
}
A global allocation.

Fields

bytes: List<Option<u8>>

The raw bytes of the allocation. None represents uninitialized bytes.

relocations: List<(Size, Relocation)>

Cross-references pointing to other global allocations, together with an offset, expressing where this allocation should put the pointer. Note that the pointers created due to relocations overwrite the data given by bytes.

align: Align

The alignment with which this global shall be allocated.