Map

Struct Map 

pub struct Map<K, V>(pub(crate) GcCow<HashMap<K, V>>)
where
    K: Obj,
    V: Obj;
Garbage-collected hash map implementing Copy. This implements Ord but the order is not meaningful; this is just so one can use BTreeMaps. In particular, the order might differ across two runs of the same program.

Tuple Fields

0: GcCow<HashMap<K, V>>

Implementations



impl<K, V> Map<K, V>
where K: Obj, V: Obj,

pub fn new() -> Map<K, V>

Creates an empty Map.

pub fn get(&self, k: K) -> Option<V>

Returns the value to the key k. Returns None if the key k is not in the Map.

pub fn index_at(&self, k: K) -> V

The indexing operator: specr translates a[b] to a.index_at(b).

pub fn remove(&mut self, k: K) -> Option<V>

Removes k from the map. If the pair (k, v) was in the map, Some(v) is returned. Otherwise, None is returned.

pub fn contains_key(&self, k: K) -> bool

Checks whether self contains k.

pub fn insert(&mut self, k: K, v: V) -> Option<V>

Insert a key/value mapping into a map. If the map already has a mapping for the given key the previous value is overwritten.

pub fn try_insert(&mut self, k: K, v: V) -> Result<(), ()>

Like insert, but fails if k was already in the map.

pub fn keys(self) -> impl Iterator<Item = K>

An iterator over all keys.

pub fn values(self) -> impl Iterator<Item = V>

An iterator over all values.

pub fn len(self) -> Int

Returns the number of elements in self.

pub fn is_empty(self) -> bool

Returns true if the map contains no elements.



impl<K, V> Map<K, V>
where K: Obj, V: Obj,

pub fn iter(self) -> ConsumingIter<(K, V)> ⓘ

Returns an iterator over all (key, value) pairs.