Struct PointeeInfo
pub struct PointeeInfo {
pub layout: LayoutStrategy,
pub inhabited: bool,
pub unsafe_cells: UnsafeCellStrategy,
pub freeze: bool,
pub unpin: bool,
}Expand description
Describes what we know about data behind a pointer.
Fields
layout: LayoutStrategyinhabited: boolunsafe_cells: UnsafeCellStrategyIndicates where the UnsafeCell in this type are, which permit interior mutability.
freeze: boolWhether the pointee implements the Freeze trait. This is used to determine
whether the bytes “outside” the pointee have interior mutability.
unpin: boolTrait Implementations
impl Clone for PointeeInfo
impl Clone for PointeeInfo
fn clone(&self) -> PointeeInfo
fn clone(&self) -> PointeeInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PointeeInfo
impl Debug for PointeeInfo
impl Debug for PointeeInfo
impl<'de> Deserialize<'de> for PointeeInfo
impl<'de> Deserialize<'de> for PointeeInfo
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PointeeInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PointeeInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PointeeInfo
impl Hash for PointeeInfo
impl Hash for PointeeInfo
impl Ord for PointeeInfo
impl Ord for PointeeInfo
fn cmp(&self, other: &PointeeInfo) -> Ordering
fn cmp(&self, other: &PointeeInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
impl PartialEq for PointeeInfo
impl PartialEq for PointeeInfo
impl PartialOrd for PointeeInfo
impl PartialOrd for PointeeInfo
impl Serialize for PointeeInfo
impl Serialize for PointeeInfo
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PointeeInfo