Struct Pointer
pub struct Pointer<Provenance>where
Provenance: Obj,{
pub thin_pointer: ThinPointer<Provenance>,
pub metadata: Option<PointerMeta<Provenance>>,
}Expand description
A “pointer” is the thin pointer with optionally some metadata, making it a wide pointer. This corresponds to the Rust raw pointer types, as well as references and boxes.
Fields
thin_pointer: ThinPointer<Provenance>metadata: Option<PointerMeta<Provenance>>Trait Implementations
impl<Provenance> Copy for Pointer<Provenance>where
Provenance: Copy + Obj,
impl<'de, Provenance> Deserialize<'de> for Pointer<Provenance>where
Provenance: Obj + Deserialize<'de>,
impl<'de, Provenance> Deserialize<'de> for Pointer<Provenance>where
Provenance: Obj + Deserialize<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Pointer<Provenance>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Pointer<Provenance>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<Provenance> Eq for Pointer<Provenance>where
Provenance: Eq + Obj,
impl<Provenance> Ord for Pointer<Provenance>where
Provenance: Ord + Obj,
impl<Provenance> Ord for Pointer<Provenance>where
Provenance: Ord + Obj,
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
impl<Provenance> PartialOrd for Pointer<Provenance>where
Provenance: PartialOrd + Obj,
impl<Provenance> PartialOrd for Pointer<Provenance>where
Provenance: PartialOrd + Obj,
impl<Provenance> Serialize for Pointer<Provenance>where
Provenance: Obj + Serialize,
impl<Provenance> Serialize for Pointer<Provenance>where
Provenance: Obj + Serialize,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<Provenance> StructuralPartialEq for Pointer<Provenance>where
Provenance: PartialEq + Obj,