Struct Program
pub struct Program {
pub functions: Map<FnName, Function>,
pub start: FnName,
pub globals: Map<GlobalName, Global>,
pub traits: Map<TraitName, Set<TraitMethodName>>,
pub vtables: Map<VTableName, VTable>,
}Expand description
A closed MiniRust program.
Fields
functions: Map<FnName, Function>Associate a function with each declared function name.
start: FnNameThe function where execution starts.
globals: Map<GlobalName, Global>Associate each global name with the associated global.
traits: Map<TraitName, Set<TraitMethodName>>Stores all traits and method names which are available for dynamic dispatch.
vtables: Map<VTableName, VTable>Store the vtables with method tables and layout information.