Struct TreeBorrowsMemory
pub struct TreeBorrowsMemory<T>where
T: Target + Obj,{
params: TreeBorrowsParams,
mem: BasicMemory<T, List<Int>, TreeBorrowsAllocationExtra>,
}Fields
params: TreeBorrowsParamsmem: BasicMemory<T, List<Int>, TreeBorrowsAllocationExtra>Trait Implementations
impl<T> Clone for TreeBorrowsMemory<T>
impl<T> Clone for TreeBorrowsMemory<T>
fn clone(&self) -> TreeBorrowsMemory<T>
fn clone(&self) -> TreeBorrowsMemory<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T> Copy for TreeBorrowsMemory<T>
impl<T> Debug for TreeBorrowsMemory<T>
impl<T> Debug for TreeBorrowsMemory<T>
impl<'de, T> Deserialize<'de> for TreeBorrowsMemory<T>where
T: Target + Obj + Deserialize<'de>,
impl<'de, T> Deserialize<'de> for TreeBorrowsMemory<T>where
T: Target + Obj + Deserialize<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TreeBorrowsMemory<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TreeBorrowsMemory<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<T> Eq for TreeBorrowsMemory<T>
impl<T> Hash for TreeBorrowsMemory<T>
impl<T> Hash for TreeBorrowsMemory<T>
impl<T> Memory for TreeBorrowsMemory<T>
impl<T> Memory for TreeBorrowsMemory<T>
type Provenance = (AllocId, List<Int>)
type Provenance = (AllocId, List<Int>)
The type of pointer provenance.
type FrameExtra = TreeBorrowsFrameExtra
type FrameExtra = TreeBorrowsFrameExtra
Extra information for each stack frame.
type T = T
type T = T
The target information.
This doesn’t really belong to the memory, but avoids having to quantify over both
memory and target everywhere.
type Params = TreeBorrowsParams
type Params = TreeBorrowsParams
Parameters controlling memory model behavior, passed at construction time.
fn new(params: TreeBorrowsParams) -> TreeBorrowsMemory<T>
fn new(params: TreeBorrowsParams) -> TreeBorrowsMemory<T>
Create a new instance of the memory model with the given parameters.
fn allocate(
&mut self,
kind: AllocationKind,
size: Size,
align: Align,
) -> NdResult<ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, TerminationInfo>
fn allocate( &mut self, kind: AllocationKind, size: Size, align: Align, ) -> NdResult<ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, TerminationInfo>
Create a new allocation.
The initial contents of the allocation are
AbstractByte::Uninit. Read morefn deallocate(
&mut self,
ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>,
kind: AllocationKind,
size: Size,
align: Align,
) -> Result<(), TerminationInfo>
fn deallocate( &mut self, ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, kind: AllocationKind, size: Size, align: Align, ) -> Result<(), TerminationInfo>
Remove an allocation.
fn load(
&mut self,
ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>,
len: Size,
align: Align,
) -> Result<List<AbstractByte<<TreeBorrowsMemory<T> as Memory>::Provenance>>, TerminationInfo>
fn load( &mut self, ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, len: Size, align: Align, ) -> Result<List<AbstractByte<<TreeBorrowsMemory<T> as Memory>::Provenance>>, TerminationInfo>
Read some bytes from memory. Read more
fn store(
&mut self,
ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>,
bytes: List<AbstractByte<<TreeBorrowsMemory<T> as Memory>::Provenance>>,
align: Align,
) -> Result<(), TerminationInfo>
fn store( &mut self, ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, bytes: List<AbstractByte<<TreeBorrowsMemory<T> as Memory>::Provenance>>, align: Align, ) -> Result<(), TerminationInfo>
Write some bytes to memory.
fn dereferenceable(
&self,
ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>,
len: Size,
) -> Result<(), TerminationInfo>
fn dereferenceable( &self, ptr: ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, len: Size, ) -> Result<(), TerminationInfo>
Test whether the given pointer is dereferenceable for the given size.
fn retag_ptr(
&mut self,
frame_extra: &mut <TreeBorrowsMemory<T> as Memory>::FrameExtra,
ptr: Pointer<<TreeBorrowsMemory<T> as Memory>::Provenance>,
ptr_type: PtrType,
fn_entry: bool,
fn_implicit_writes: bool,
vtable_lookup: impl Fn(ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>) -> VTable + 'static,
) -> Result<Pointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, TerminationInfo>
fn retag_ptr( &mut self, frame_extra: &mut <TreeBorrowsMemory<T> as Memory>::FrameExtra, ptr: Pointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, ptr_type: PtrType, fn_entry: bool, fn_implicit_writes: bool, vtable_lookup: impl Fn(ThinPointer<<TreeBorrowsMemory<T> as Memory>::Provenance>) -> VTable + 'static, ) -> Result<Pointer<<TreeBorrowsMemory<T> as Memory>::Provenance>, TerminationInfo>
Retag the given pointer, which has the given type.
fn_entry indicates whether this is one of the special retags that happen
right at the top of each function. Read morefn new_call() -> <TreeBorrowsMemory<T> as Memory>::FrameExtra
fn new_call() -> <TreeBorrowsMemory<T> as Memory>::FrameExtra
Create the extra information for a stack frame.
fn end_call(
&mut self,
extra: <TreeBorrowsMemory<T> as Memory>::FrameExtra,
) -> Result<(), TerminationInfo>
fn end_call( &mut self, extra: <TreeBorrowsMemory<T> as Memory>::FrameExtra, ) -> Result<(), TerminationInfo>
Memory model hook invoked at the end of each function call.
fn leak_check(&self) -> Result<(), TerminationInfo>
fn leak_check(&self) -> Result<(), TerminationInfo>
Check if there are any memory leaks.
fn signed_dereferenceable(
&self,
ptr: ThinPointer<Self::Provenance>,
len: Int,
) -> Result<(), TerminationInfo>
fn signed_dereferenceable( &self, ptr: ThinPointer<Self::Provenance>, len: Int, ) -> Result<(), TerminationInfo>
A derived form of
dereferenceable that works with a signed notion of “length”.impl<T> Ord for TreeBorrowsMemory<T>
impl<T> Ord for TreeBorrowsMemory<T>
fn cmp(&self, other: &TreeBorrowsMemory<T>) -> Ordering
fn cmp(&self, other: &TreeBorrowsMemory<T>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
impl<T> PartialEq for TreeBorrowsMemory<T>
impl<T> PartialEq for TreeBorrowsMemory<T>
impl<T> PartialOrd for TreeBorrowsMemory<T>where
T: PartialOrd + Target + Obj,
impl<T> PartialOrd for TreeBorrowsMemory<T>where
T: PartialOrd + Target + Obj,
impl<T> Serialize for TreeBorrowsMemory<T>
impl<T> Serialize for TreeBorrowsMemory<T>
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<T> StructuralPartialEq for TreeBorrowsMemory<T>