Struct TupleHeadLayout
pub struct TupleHeadLayout {
pub end: Size,
pub align: Align,
pub packed_align: Option<Align>,
}Expand description
Describes what is needed to define the layout of the sized head of a tuple (head.., tail).
Fields
end: SizeThe offset where the head ends and tail starts.
This is the end of the last sized field; it is not necessarily aligned to align.
align: AlignThe alignment of the head. This is the maximal alignment of any sized field and capped to the packed alignment.
packed_align: Option<Align>If this is Some(a) the alignment of the tail will be capped at this value.
Must be None for sized tuples.
Implementations
impl TupleHeadLayout
impl TupleHeadLayout
pub fn tail_offset(self, tail_align: Align) -> Size
pub fn tail_offset(self, tail_align: Align) -> Size
Where the tail starts, given the aligment of the tail type.
pub fn full_size_and_align(
self,
tail_size: Size,
tail_align: Align,
) -> (Size, Align)
pub fn full_size_and_align( self, tail_size: Size, tail_align: Align, ) -> (Size, Align)
The size and alignment of the full tuple, including the tail. Given the size and alignment of the tail type.
pub fn head_size_and_align(self) -> (Size, Align)
pub fn head_size_and_align(self) -> (Size, Align)
Returns the size and alignment of the tuple when there is no tail.