Struct VTable
pub struct VTable {
pub trait_name: TraitName,
pub size: Size,
pub align: Align,
pub cells: List<(Size, Size)>,
pub methods: Map<TraitMethodName, FnName>,
}Expand description
A vtable for a trait-type pair. This is pointed to by the trait object metadata.
Fields
trait_name: TraitNameWhat trait this vtable is for. All vtables for this trait name have implementation for same set of methods.
size: SizeThe size of the type.
align: AlignThe alignment of the type.
cells: List<(Size, Size)>Offset and sizes of UnsafeCell in this vtable.
methods: Map<TraitMethodName, FnName>The implementations of trait methods.