Variant

Struct Variant 

pub struct Variant {
    pub ty: Type,
    pub tagger: Map<Size, (IntType, Int)>,
}

Fields

ty: Type

The actual type of the variant.

tagger: Map<Size, (IntType, Int)>

The information on where to store which values to write the tag. MUST NOT touch any bytes written by the actual type of the variant and vice versa. This is because we allow references/pointers to (enum) fields which should be able to dereference without having to deal with the tag.