Enum CallingConvention
pub enum CallingConvention {
Rust,
C,
}Expand description
The CallingConvention defines how function arguments and return values are passed.
The assumption is that if caller and callee agree on the calling convention, and all arguments and the return types
pass check_abi_compatibility, then this implies they are ABI-compatible on real implementations.
Variants