Enum LayoutStrategy
pub enum LayoutStrategy {
Sized(Size, Align),
Slice(Size, Align),
TraitObject(TraitName),
Tuple {
head: TupleHeadLayout,
tail: GcCow<LayoutStrategy>,
},
}Expand description
Describes how the size and align of the value can be determined.
Variants
Sized(Size, Align)
The type is statically Sized with the given size and align.
Slice(Size, Align)
The type contains zero or more elements of the inner layout. The total size is a multiple of the element size and the align is exactly the element align.
TraitObject(TraitName)
The size of the type must be looked up in the VTable of a wide pointer. Additionally, the vtable must be for the given trait.
Tuple
The type consists of a sized head an unsized tail.
Implementations
impl LayoutStrategy
impl LayoutStrategy
pub fn is_sized(self) -> bool
pub fn expect_size(self, msg: &str) -> Size
pub fn expect_size(self, msg: &str) -> Size
Returns the size when the type must be statically sized.
pub fn expect_align(self, msg: &str) -> Align
pub fn expect_align(self, msg: &str) -> Align
Returns the alignment when the type must be statically sized.
pub fn compute_size_and_align<Provenance>(
self,
meta: Option<PointerMeta<Provenance>>,
vtables: impl FnOnce(ThinPointer<Provenance>) -> VTable,
) -> (Size, Align)where
Provenance: Obj,
pub fn compute_size_and_align<Provenance>(
self,
meta: Option<PointerMeta<Provenance>>,
vtables: impl FnOnce(ThinPointer<Provenance>) -> VTable,
) -> (Size, Align)where
Provenance: Obj,
Computes the dynamic size and alignment, but the caller must provide compatible metadata.
The size and align of unsized structs depend on each other, thus we must recursively compute them at the same time.
pub fn meta_kind(self) -> PointerMetaKind
pub fn meta_kind(self) -> PointerMetaKind
Returns the metadata kind which is needed to compute this strategy,
i.e machine.check_pointer_metadata(meta, self.meta_kind()).is_ok() implies machine.compute_*(meta) is well-defined.