Enum Terminator
pub enum Terminator {
Goto(BbName),
Switch {
value: ValueExpr,
cases: Map<Int, BbName>,
fallback: BbName,
},
Unreachable,
Intrinsic {
intrinsic: IntrinsicOp,
arguments: List<ValueExpr>,
ret: PlaceExpr,
next_block: Option<BbName>,
},
Call {
callee: ValueExpr,
calling_convention: CallingConvention,
arguments: List<ArgumentExpr>,
ret: PlaceExpr,
next_block: Option<BbName>,
unwind_block: Option<BbName>,
},
Return,
StartUnwind {
unwind_payload: ValueExpr,
unwind_block: BbName,
},
StopUnwind(BbName),
ResumeUnwind,
}Variants
Goto(BbName)
Just jump to the next block.
Switch
value needs to evaluate to a Value::Int.
cases map those values to blocks to jump to and therefore have to have the equivalent type.
If no value matches we fall back to the block given in fallback.
Unreachable
If this is ever executed, we have UB.
Intrinsic
Invoke the given intrinsic operation with the given arguments.
Intrinsics are langauge primitives that can have arbitrary side-effects, including divergence.
Fields
intrinsic: IntrinsicOpCall
Call the given function with the given arguments.
Fields
callee: ValueExprWhat function or method to call. This must evaluate to a function pointer and for safe behaviour, the functions signature must match the arguments.
Dynamic dispatch is represented with the callee being the result of VTableMethodLookup(GetMetadata(self)),
and the self argument appropriately cast to a thin pointer type.
calling_convention: CallingConventionThe calling convention to use for this call.
arguments: List<ArgumentExpr>The arguments to pass.
next_block: Option<BbName>The block to jump to when this call returns.
If None, UB will be raised when the function returns.
unwind_block: Option<BbName>The block to jump to when this call unwinds.
If None, UB will be raised when the function unwinds.
This comes with a well-formedness requirement: if the current block is a regular block,
unwind_block must be either a cleanup block or a catch block;
otherwise, unwind_block must be a terminating block.
Return
Return from the current function.
StartUnwind
Starts unwinding, jump to the indicated cleanup block.
Fields
StopUnwind(BbName)
Stops unwinding, jump to the indicated regular block. This also removes the topmost unwinding payload. UB if not currently unwinding.
ResumeUnwind
Ends this function call. The unwinding should continue at the caller’s stack frame.