Struct Int
pub struct Int(IntInner);Expand description
Garbage collected big integer that implements Copy and supports construction in const contexts.
Tuple Fields
0: IntInnerImplementations
impl Int
impl Int
pub fn is_power_of_two(self) -> bool
pub fn is_power_of_two(self) -> bool
Returns true if self is a power of two. false otherwise.
pub fn next_power_of_two(self) -> Int
pub fn next_power_of_two(self) -> Int
Returns the smallest power of two greater than or equal to self.
pub fn next_multiple_of(self, other: Int) -> Int
pub fn next_multiple_of(self, other: Int) -> Int
If other is positive, calculates the smallest value greater than or equal to self that is a multiple of other.
If other is negative, calculates the largest value less than or equal to self that is a multiple of other.
Panics if other is zero.
pub fn checked_div(self, other: Int) -> Option<Int>
pub fn checked_div(self, other: Int) -> Option<Int>
Checked integer division.
Returns None if and only if other == 0.
pub fn trailing_zeros(self) -> Option<Int>
pub fn trailing_zeros(self) -> Option<Int>
Returns the number of least-significant bits that are zero or None if the entire number is zero.
pub fn div_euclid(self, other: Int) -> Int
pub fn div_euclid(self, other: Int) -> Int
Calculates Euclidean division: the result is rounded towards -INF
for other > 0 and towards +INF for other < 0.
The result n satisfies self == n * other + self.rem_euclid(other).
pub fn rem_euclid(self, other: Int) -> Int
pub fn rem_euclid(self, other: Int) -> Int
Calculate nonnegative remainder of self (mod other).
The return value is in the range 0..other.abs().
pub fn bring_in_bounds(self, signed: Signedness, size: Size) -> Int
pub fn bring_in_bounds(self, signed: Signedness, size: Size) -> Int
Returns the unique value that is equal to self modulo 2^size.bits()
and within the bounds of a finite integer type with the given signedness and size.
If signed == Unsigned the result is in the interval 0..2^size.bits().
Otherwise it is in the interval -2^(size.bits()-1) .. 2^(size.bits()-1).
size must not be zero.
pub fn in_bounds(self, signed: Signedness, size: Size) -> bool
pub fn in_bounds(self, signed: Signedness, size: Size) -> bool
Tests whether an integer is in-bounds of a finite integer type.