Struct Machine
pub struct Machine<M>where
M: Memory + Obj,{
prog: Program,
mem: ConcurrentMemory<M>,
intptrcast: IntPtrCast<<M as Memory>::Provenance>,
threads: List<Thread<M>>,
active_thread: Int,
synchronized_threads: Set<Int>,
locks: List<LockState>,
global_ptrs: Map<GlobalName, ThinPointer<<M as Memory>::Provenance>>,
fn_ptrs: Map<FnName, ThinPointer<<M as Memory>::Provenance>>,
vtable_ptrs: Map<VTableName, ThinPointer<<M as Memory>::Provenance>>,
stdout: DynWrite,
stderr: DynWrite,
}Expand description
This type contains everything that needs to be tracked during the execution of a MiniRust program.
Fields
prog: Programmem: ConcurrentMemory<M>intptrcast: IntPtrCast<<M as Memory>::Provenance>threads: List<Thread<M>>active_thread: Intsynchronized_threads: Set<Int>locks: List<LockState>global_ptrs: Map<GlobalName, ThinPointer<<M as Memory>::Provenance>>fn_ptrs: Map<FnName, ThinPointer<<M as Memory>::Provenance>>vtable_ptrs: Map<VTableName, ThinPointer<<M as Memory>::Provenance>>stdout: DynWritestderr: DynWriteImplementations
impl<M> Machine<M>where
M: Memory + Obj,
impl<M> Machine<M>where
M: Memory + Obj,
pub fn new( prog: Program, mem_params: <M as Memory>::Params, stdout: DynWrite, stderr: DynWrite, ) -> NdResult<Machine<M>, TerminationInfo>
pub fn step(&mut self) -> NdResult<(), TerminationInfo>
pub fn step(&mut self) -> NdResult<(), TerminationInfo>
To run a MiniRust program, call this in a loop until it throws an Err (UB or termination).
pub fn lock_create(&mut self) -> Int
pub fn lock_acquire(&mut self, lock_id: Int) -> Result<(), TerminationInfo>
pub fn lock_release(&mut self, lock_id: Int) -> NdResult<(), TerminationInfo>