Struct Map
pub struct Map<K, V>(pub(crate) GcCow<HashMap<K, V>>)
where
K: Obj,
V: Obj;Expand description
Garbage-collected hash map implementing Copy.
This implements Ord but the order is not meaningful; this is just so one can use BTreeMaps.
In particular, the order might differ across two runs of the same program.
Tuple Fields
0: GcCow<HashMap<K, V>>Implementations
impl<K, V> Map<K, V>where
K: Obj,
V: Obj,
impl<K, V> Map<K, V>where
K: Obj,
V: Obj,
pub fn get(&self, k: K) -> Option<V>
pub fn get(&self, k: K) -> Option<V>
Returns the value to the key k.
Returns None if the key k is not in the Map.
pub fn index_at(&self, k: K) -> V
pub fn index_at(&self, k: K) -> V
The indexing operator:
specr translates a[b] to a.index_at(b).
pub fn remove(&mut self, k: K) -> Option<V>
pub fn remove(&mut self, k: K) -> Option<V>
Removes k from the map.
If the pair (k, v) was in the map, Some(v) is returned.
Otherwise, None is returned.
pub fn contains_key(&self, k: K) -> bool
pub fn contains_key(&self, k: K) -> bool
Checks whether self contains k.
pub fn insert(&mut self, k: K, v: V) -> Option<V>
pub fn insert(&mut self, k: K, v: V) -> Option<V>
Insert a key/value mapping into a map. If the map already has a mapping for the given key the previous value is overwritten.
pub fn try_insert(&mut self, k: K, v: V) -> Result<(), ()>
pub fn try_insert(&mut self, k: K, v: V) -> Result<(), ()>
Like insert, but fails if k was already in the map.