Type Alias Address
pub type Address = Int;Expand description
An “address” is a location in memory. This corresponds to the actual location in the real program. We make it a mathematical integer, but of course it is bounded by the size of the address space.
Aliased Type
pub struct Address(/* private fields */);